@@ -4,6 +4,7 @@ from typing import List, Tuple
 import cooptools.geometry as geo
 from scipy.spatial import ConvexHull
 from shapely.geometry import Polygon
+from cooptools.geometry import collinear_points
 
 
 class Rectangle:
@@ -52,6 +53,17 @@ class Line:
         xdiff = (self.origin.x - self.destination.x, other_line.origin.x - other_line.destination.x)
         ydiff = (self.origin.y - self.destination.y, other_line.origin.y - other_line.destination.y)
 
+        # handle meet at ends case:
+        if self.origin in [other_line.origin, other_line.destination]:
+            return self.origin
+        elif self.destination in [other_line.origin, other_line.destination]:
+            return self.destination
+
+        # handle collinear lines
+        if collinear_points([self.origin.as_tuple(), self.destination.as_tuple(), other_line.origin.as_tuple(),
+                             other_line.destination.as_tuple()]):
+            raise Exception("Lines are collinear")
+
         def det(a, b):
             return a[0] * b[1] - a[1] * b[0]
 
